@@ -150,7 +150,8 @@ def decrease_writes_in_units(
 
 
 def increase_reads_in_percent(
-        current_provisioning, percent, max_provisioned_reads, log_tag):
+        current_provisioning, percent, max_provisioned_reads,
+        consumed_read_units_percent, log_tag):
     """ Increase the current_provisioning with percent %
 
     :type current_provisioning: int
@@ -160,11 +161,23 @@ def increase_reads_in_percent(
     :type max_provisioned_reads: int
     :param max_provisioned_reads: Configured max provisioned reads
     :returns: int -- New provisioning value
+    :type consumed_read_units_percent: float
+    :param consumed_read_units_percent: Number of consumed read units
     :type log_tag: str
     :param log_tag: Prefix for the log
     """
-    increase = int(math.ceil(float(current_provisioning)*(float(percent)/100)))
-    updated_provisioning = current_provisioning + increase
+    current_provisioning = float(current_provisioning)
+    consumed_read_units_percent = float(consumed_read_units_percent)
+    consumption_based_current_provisioning = \
+        float(math.ceil(current_provisioning*(consumed_read_units_percent/100)))
+
+    if consumption_based_current_provisioning > current_provisioning:
+        increase = int(
+            math.ceil(consumption_based_current_provisioning*(percent/100)))
+        updated_provisioning = consumption_based_current_provisioning + increase
+    else:
+        increase = int(math.ceil(current_provisioning*(percent/100)))
+        updated_provisioning = current_provisioning + increase
 
     if max_provisioned_reads > 0:
         if updated_provisioning > max_provisioned_reads:
@@ -184,7 +197,8 @@ def increase_reads_in_percent(
 
 
 def increase_reads_in_units(
-        current_provisioning, units, max_provisioned_reads, log_tag):
+        current_provisioning, units, max_provisioned_reads,
+        consumed_read_units_percent, log_tag):
     """ Increase the current_provisioning with units units
 
     :type current_provisioning: int
@@ -195,10 +209,21 @@ def increase_reads_in_units(
     :type max_provisioned_reads: int
     :param max_provisioned_reads: Configured max provisioned reads
     :returns: int -- New provisioning value
+    :type consumed_read_units_percent: float
+    :param consumed_read_units_percent: Number of consumed read units
     :type log_tag: str
     :param log_tag: Prefix for the log
     """
-    updated_provisioning = int(current_provisioning) + int(units)
+    units = int(units)
+    current_provisioning = float(current_provisioning)
+    consumed_read_units_percent = float(consumed_read_units_percent)
+    consumption_based_current_provisioning = \
+        int(math.ceil(current_provisioning*(consumed_read_units_percent/100)))
+
+    if consumption_based_current_provisioning > current_provisioning:
+        updated_provisioning = consumption_based_current_provisioning + units
+    else:
+        updated_provisioning = int(current_provisioning) + units
 
     if max_provisioned_reads > 0:
         if updated_provisioning > max_provisioned_reads:
@@ -218,7 +243,8 @@ def increase_reads_in_units(
 
 
 def increase_writes_in_percent(
-        current_provisioning, percent, max_provisioned_writes, log_tag):
+        current_provisioning, percent, max_provisioned_writes,
+        consumed_write_units_percent, log_tag):
     """ Increase the current_provisioning with percent %
 
     :type current_provisioning: int
@@ -228,11 +254,23 @@ def increase_writes_in_percent(
     :returns: int -- New provisioning value
     :type max_provisioned_writes: int
     :param max_provisioned_writes: Configured max provisioned writes
+    :type consumed_write_units_percent: float
+    :param consumed_write_units_percent: Number of consumed write units
     :type log_tag: str
     :param log_tag: Prefix for the log
     """
-    increase = int(math.ceil(float(current_provisioning)*(float(percent)/100)))
-    updated_provisioning = current_provisioning + increase
+    current_provisioning = float(current_provisioning)
+    consumed_write_units_percent = float(consumed_write_units_percent)
+    consumption_based_current_provisioning = \
+        int(math.ceil(current_provisioning*(consumed_write_units_percent/100)))
+
+    if consumption_based_current_provisioning > current_provisioning:
+        increase = int(
+            math.ceil(consumption_based_current_provisioning*(percent/100)))
+        updated_provisioning = consumption_based_current_provisioning + increase
+    else:
+        increase = int(math.ceil(current_provisioning*(float(percent)/100)))
+        updated_provisioning = current_provisioning + increase
 
     if max_provisioned_writes > 0:
         if updated_provisioning > max_provisioned_writes:
@@ -253,7 +291,8 @@ def increase_writes_in_percent(
 
 
 def increase_writes_in_units(
-        current_provisioning, units, max_provisioned_writes, log_tag):
+        current_provisioning, units, max_provisioned_writes,
+        consumed_write_units_percent, log_tag):
     """ Increase the current_provisioning with units units
 
     :type current_provisioning: int
@@ -263,10 +302,21 @@ def increase_writes_in_units(
     :returns: int -- New provisioning value
     :type max_provisioned_writes: int
     :param max_provisioned_writes: Configured max provisioned writes
+    :type consumed_write_units_percent: float
+    :param consumed_write_units_percent: Number of consumed write units
     :type log_tag: str
     :param log_tag: Prefix for the log
     """
-    updated_provisioning = int(current_provisioning) + int(units)
+    units = int(units)
+    current_provisioning = float(current_provisioning)
+    consumed_write_units_percent = float(consumed_write_units_percent)
+    consumption_based_current_provisioning = \
+        int(math.ceil(current_provisioning*(consumed_write_units_percent/100)))
+
+    if consumption_based_current_provisioning > current_provisioning:
+        updated_provisioning = consumption_based_current_provisioning + units
+    else:
+        updated_provisioning = int(current_provisioning) + units
 
     if max_provisioned_writes > 0:
         if updated_provisioning > max_provisioned_writes:
